@@ -136,6 +136,7 @@
 #' index_stats('plos')
 #' index_stats(c('plos','gbif'))
 #' index_stats(c('plos','gbif'), metric='refresh')
+#' index_stats(metric = "indices")
 #' index_stats('shakespeare', metric='completion')
 #' index_stats('shakespeare', metric='completion', completion_fields = "completion")
 #' index_stats('shakespeare', metric='fielddata')
@@ -196,8 +197,8 @@
 #'              }
 #'       }
 #' }'
-#' tokenizer_set(index = "shakespeare", body=body)
-#' index_analyze(text = "art thouh", index = "shakespeare", analyzer='my_ngram_analyzer')
+#' tokenizer_set(index = "shakespeare2", body=body)
+#' index_analyze(text = "art thouh", index = "shakespeare2", analyzer='my_ngram_analyzer')
 #'
 #' # Explicitly flush one or more indices.
 #' index_flush()
@@ -228,42 +229,37 @@ NULL
 
 #' @export
 #' @rdname index
-index_get <- function(index=NULL, features=NULL, raw=FALSE, verbose=TRUE, ...)
-{
-  conn <- connect()
-  url <- paste0(conn$base, ":", conn$port)
-  index_GET(url, index, features, raw, ...)
+index_get <- function(index=NULL, features=NULL, raw=FALSE, verbose=TRUE, ...) {
+  index_GET(index, features, raw, ...)
 }
 
 #' @export
 #' @rdname index
-index_exists <- function(index, ...)
-{
-  conn <- connect()
-  url <- paste0(conn$base, ":", conn$port, "/", index)
-  res <- HEAD(url, ...)
-  if(res$status_code == 200) TRUE else FALSE
+index_exists <- function(index, ...) {
+  checkconn()
+  url <- file.path(make_url(es_get_auth()), esc(index))
+  res <- HEAD(url, ..., make_up())
+  if (res$status_code == 200) TRUE else FALSE
 }
 
 #' @export
 #' @rdname index
-index_delete <- function(index, raw=FALSE, verbose=TRUE, ...)
-{
-  conn <- connect()
-  url <- paste0(conn$base, ":", conn$port, "/", index)
-  out <- DELETE(url, ...)
+index_delete <- function(index, raw=FALSE, verbose=TRUE, ...) {
+  checkconn()
+  url <- paste0(make_url(es_get_auth()), "/", esc(index))
+  out <- DELETE(url, make_up(), ...)
   stop_for_status(out)
-  if(verbose) message(URLdecode(out$url))
-  tt <- structure(content(out, as="text"), class="index_delete")
-  if(raw){ tt } else { es_parse(tt) }
+  if (verbose) message(URLdecode(out$url))
+  tt <- structure(content(out, as = "text"), class = "index_delete")
+  if (raw){ tt } else { es_parse(tt) }
 }
 
 #' @export
 #' @rdname index
-index_create <- function(index=NULL, body=NULL, raw=FALSE, verbose=TRUE, ...)
-{
-  conn <- connect()
-  out <- PUT(sprintf("%s:%s/%s", conn$base, conn$port, index), body=body, ...)
+index_create <- function(index=NULL, body=NULL, raw=FALSE, verbose=TRUE, ...) {
+  checkconn()
+  url <- make_url(es_get_auth())
+  out <- PUT(paste0(url, "/", index), body=body, make_up(), ...)
   stop_for_status(out)
   if(verbose) message(URLdecode(out$url))
   tt <- content(out, as="text")
@@ -272,25 +268,22 @@ index_create <- function(index=NULL, body=NULL, raw=FALSE, verbose=TRUE, ...)
 
 #' @export
 #' @rdname index
-index_close <- function(index, ...)
-{
+index_close <- function(index, ...) {
   close_open(index, "_close", ...)
 }
 
 #' @export
 #' @rdname index
-index_open <- function(index, ...)
-{
+index_open <- function(index, ...) {
   close_open(index, "_open", ...)
 }
 
 #' @export
 #' @rdname index
 index_stats <- function(index=NULL, metric=NULL, completion_fields=NULL, fielddata_fields=NULL,
-  fields=NULL, groups=NULL, level='indices', ...)
-{
-  conn <- connect()
-  url <- if(is.null(index)) file.path(e_url(conn), "_stats") else file.path(e_url(conn), cl(index), "_stats")
+  fields=NULL, groups=NULL, level='indices', ...) {
+  url <- make_url(es_get_auth())
+  url <- if(is.null(index)) file.path(url, "_stats") else file.path(url, esc(cl(index)), "_stats")
   url <- if(!is.null(metric)) file.path(url, cl(metric)) else url
   args <- ec(list(completion_fields=completion_fields, fielddata_fields=fielddata_fields,
                   fields=fields, groups=groups, level=level))
@@ -299,10 +292,9 @@ index_stats <- function(index=NULL, metric=NULL, completion_fields=NULL, fieldda
 
 #' @export
 #' @rdname index
-index_settings <- function(index="_all", ...)
-{
-  conn <- connect()
-  url <- if(is.null(index) || index == "_all") file.path(e_url(conn), "_settings") else file.path(e_url(conn), cl(index), "_settings")
+index_settings <- function(index="_all", ...) {
+  url <- make_url(es_get_auth())
+  url <- if(is.null(index) || index == "_all") file.path(url, "_settings") else file.path(url, esc(cl(index)), "_settings")
   es_GET_(url, ...)
 }
 
@@ -324,8 +316,7 @@ index_recovery <- function(index = NULL, detailed = FALSE, active_only = FALSE,
 #' @export
 #' @rdname index
 index_optimize <- function(index = NULL, max_num_segments = NULL, only_expunge_deletes = FALSE,
-  flush = TRUE, wait_for_merge = TRUE, ...)
-{
+  flush = TRUE, wait_for_merge = TRUE, ...) {
   args <- ec(list(max_num_segments = max_num_segments,
                   only_expunge_deletes = as_log(only_expunge_deletes),
                   flush = as_log(flush),
@@ -336,8 +327,7 @@ index_optimize <- function(index = NULL, max_num_segments = NULL, only_expunge_d
 
 #' @export
 #' @rdname index
-index_upgrade <- function(index = NULL, wait_for_completion = FALSE, ...)
-{
+index_upgrade <- function(index = NULL, wait_for_completion = FALSE, ...) {
   args <- ec(list(wait_for_completion = as_log(wait_for_completion)))
   es_POST_(index, "_upgrade", args, ...)
 }
@@ -345,13 +335,12 @@ index_upgrade <- function(index = NULL, wait_for_completion = FALSE, ...)
 #' @export
 #' @rdname index
 index_analyze <- function(text=NULL, field=NULL, index=NULL, analyzer=NULL, tokenizer=NULL,
-                          filters=NULL, char_filters=NULL, body=list(), ...)
-{
-  conn <- connect()
+                          filters=NULL, char_filters=NULL, body=list(), ...) {
+  url <- make_url(es_get_auth())
   if(!is.null(index))
-    url <- sprintf("%s:%s/%s/_analyze", conn$base, conn$port, cl(index))
+    url <- sprintf("%s/%s/_analyze", url, esc(cl(index)))
   else
-    url <- sprintf("%s:%s/_analyze", conn$base, conn$port)
+    url <- sprintf("%s/_analyze", url)
   args <- ec(list(text=text, analyzer=analyzer, tokenizer=tokenizer, filters=filters,
                   char_filters=char_filters, field=field))
   analyze_POST(url, args, body, ...)$tokens
@@ -359,13 +348,12 @@ index_analyze <- function(text=NULL, field=NULL, index=NULL, analyzer=NULL, toke
 
 #' @export
 #' @rdname index
-index_flush <- function(index=NULL, force=FALSE, full=FALSE, wait_if_ongoing=FALSE, ...)
-{
-  conn <- connect()
+index_flush <- function(index=NULL, force=FALSE, full=FALSE, wait_if_ongoing=FALSE, ...) {
+  url <- make_url(es_get_auth())
   if(!is.null(index))
-    url <- sprintf("%s:%s/%s/_flush", conn$base, conn$port, cl(index))
+    url <- sprintf("%s/%s/_flush", url, esc(cl(index)))
   else
-    url <- sprintf("%s:%s/_flush", conn$base, conn$port)
+    url <- sprintf("%s/_flush", url)
   args <- ec(list(force=as_log(force), full=as_log(full), wait_if_ongoing=as_log(wait_if_ongoing)))
   cc_POST(url, args, ...)
 }
@@ -373,36 +361,37 @@ index_flush <- function(index=NULL, force=FALSE, full=FALSE, wait_if_ongoing=FAL
 #' @export
 #' @rdname index
 index_clear_cache <- function(index=NULL, filter=FALSE, filter_keys=NULL, fielddata=FALSE,
-                              query_cache=FALSE, id_cache=FALSE, ...)
-{
-  conn <- connect()
+                              query_cache=FALSE, id_cache=FALSE, ...) {
+  url <- make_url(es_get_auth())
   if(!is.null(index))
-    url <- sprintf("%s:%s/%s/_cache/clear", conn$base, conn$port, cl(index))
+    url <- sprintf("%s/%s/_cache/clear", url, esc(cl(index)))
   else
-    url <- sprintf("%s:%s/_cache/clear", conn$base, conn$port)
+    url <- sprintf("%s/_cache/clear", url)
   args <- ec(list(filter=as_log(filter), filter_keys=filter_keys, fielddata=as_log(fielddata),
                   query_cache=as_log(query_cache), id_cache=as_log(id_cache)))
   cc_POST(url, args, ...)
 }
 
 close_open <- function(index, which, ...){
-  conn <- connect()
-  url <- sprintf("%s:%s/%s/%s", conn$base, conn$port, index, which)
-  out <- POST(url, ...)
+  checkconn()
+  url <- make_url(es_get_auth())
+  url <- sprintf("%s/%s/%s", url, esc(index), which)
+  out <- POST(url, make_up(), ...)
   stop_for_status(out)
   content(out)
 }
 
 es_GET_wrap1 <- function(index, which, args=list(), ...){
-  conn <- connect()
-  url <- if(is.null(index)) file.path(e_url(conn), which) else file.path(e_url(conn), cl(index), which)
+  url <- make_url(es_get_auth())
+  url <- if(is.null(index)) file.path(url, which) else file.path(url, esc(cl(index)), which)
   es_GET_(url, args, ...)
 }
 
 es_POST_ <- function(index, which, args=list(), ...){
-  conn <- connect()
-  url <- if(is.null(index)) file.path(e_url(conn), which) else file.path(e_url(conn), cl(index), which)
-  tt <- POST(url, query=args, ...)
+  checkconn()
+  url <- make_url(es_get_auth())
+  url <- if(is.null(index)) file.path(url, which) else file.path(url, esc(cl(index)), which)
+  tt <- POST(url, query=args, make_up(), ...)
   if(tt$status_code > 202) stop(content(tt)$error)
   jsonlite::fromJSON(content(tt, "text"), FALSE)
 }
@@ -410,22 +399,25 @@ es_POST_ <- function(index, which, args=list(), ...){
 e_url <- function(x) paste0(x$base, ":", x$port)
 
 analyze_GET <- function(url, args, ...){
-  out <- GET(url, query=args, ...)
+  checkconn()
+  out <- GET(url, query=args, make_up(), ...)
   stop_for_status(out)
   tt <- content(out, as = "text")
   jsonlite::fromJSON(tt)
 }
 
 analyze_POST <- function(url, args, body, ...){
+  checkconn()
   body <- check_inputs(body)
-  out <- POST(url, query=args, body=body, ...)
+  out <- POST(url, query=args, body=body, make_up(), ...)
   stop_for_status(out)
   tt <- content(out, as = "text")
   jsonlite::fromJSON(tt)
 }
 
 cc_POST <- function(url, args, ...){
-  tt <- POST(url, body=args, encode = "json", ...)
+  checkconn()
+  tt <- POST(url, body=args, encode = "json", make_up(), ...)
   if(tt$status_code > 202) geterror(tt)
   res <- content(tt, as = "text")
   jsonlite::fromJSON(res, FALSE)
