@@ -35,5 +35,5 @@
 #' }
 
 scroll <- function(scroll_id, scroll="1m", raw=FALSE, ...){
-  search_POST(path = "_search/scroll", args=list(scroll=scroll, scroll_id=scroll_id), body=NULL, raw=raw, ...)
+  scroll_POST(path = "_search/scroll", args=list(scroll=scroll), body=scroll_id, raw=raw, ...)
 }
